@@ -7,10 +7,10 @@ fn main() {
 
     let html = format!(
         r#"<!DOCTYPE html>
-<style type="text/css">{stylesheet}</style>
-<p class="{messageClass}">Hello World</p>"#,
-        stylesheet = css.stylesheet,
-        messageClass = css.get("message")
+<style type="text/css">{}</style>
+<p class="{}">Hello World</p>"#,
+        css,
+        css.id("message").unwrap()
     );
 
     println!("{}", html);
