@@ -18,28 +18,29 @@ fn include_css_module_with_name() {
 fn css_module_contains_class() {
     let css = include_css_module!("simple.css");
 
-    assert!(css.contains("testOne"));
+    assert!(css.id("testOne").is_ok());
 }
 
 #[test]
 fn css_module_does_not_contain_class() {
     let css = include_css_module!("simple.css");
 
-    assert_eq!(false, css.contains("testFour"));
+    assert!(css.id("testFour").is_err());
 }
 
 #[test]
 fn css_module_get_class() {
     let css = include_css_module!("simple.css");
+    let stylesheet = format!("{}", css);
     let starts_with = ".macros_css_module_get_class_";
 
-    assert_ne!("testOne", css.get("testOne"));
-    assert_eq!(css.stylesheet[0..starts_with.len()], starts_with[..]);
+    assert_ne!("testOne", css.id("testOne").unwrap());
+    assert_eq!(stylesheet[0..starts_with.len()], starts_with[..]);
 }
 
 #[test]
 fn css_module_get_missing_class() {
     let css = include_css_module!("simple.css");
 
-    assert_eq!("testFour", css.get("testFour"));
+    assert_eq!("testFour", css.id("testFour").unwrap_err());
 }
